##  Add Initial Data
Import initial data into your inventory using the following features:
  * Integrations: Use out-of-the-box integrations and discoveries to populate your inventory. For a list of available integrations, see [Discovery and Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how SAP LeanIX integrates with various systems, automates data syncing, enhances collaboration, and provides the reference catalog to ensure accurate and up-to-date information in your workspace.").
  * AI agent discovery: Upload AI agents through the API or set up integrations with Microsoft Entra ID, Google Cloud Engine, or SAP Cloud ALM to discover agents. Review discovered agents in the AI agent discovery inbox and add relevant ones to your inventory. For details, see [AI Agent Discovery](https://help.sap.com/docs/leanix/ea/ai-agent-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Discover AI agents and MCP servers by setting up integrations with agent-building platforms and registry systems. Review discovered items in the AI agent discovery inbox and add relevant ones to your inventory.").
  * Reference catalog: Link catalog items for SAP AI agents (a subtype of applications) and AI models (a subtype of IT components) to your fact sheets. This lets you ensure high data quality and streamline the import process. For details, see:
    * [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling.")
    * [IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information.")
  * SAP suggestions: You can activate the optional feature SAP suggestions in your landscape to preview SAP suggestions for AI agents and applications in reports and create fact sheets from these suggestions. This lets you complete your inventory while ensuring high data quality. For details, see [SAP Suggestions in Your Landscape Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/sap-suggestions?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional extension to the meta model to view SAP suggestions for AI agents and applications in reports.").
